from typing import Union
from fastapi import FastAPI
from pyexql.validate import get_sf


app = FastAPI()


@app.get("/")
def read_root():
    return get_sf()


@app.get("/items/{item_id}")
def read_item(item_id: int, q: Union[str, None] = None):
    return {"item_id": item_id, "q": q}



#!/usr/bin/env python
import os
import snowflake.connector
from dotenv import load_dotenv

load_dotenv()


def get_sf():
    result = {}
    # Gets the version
    ctx = snowflake.connector.connect(
        user=os.environ.get('sf_user'),
        password=os.environ.get('sf_pass'),
        account=os.environ.get('sf_acct'),
    )
    cs = ctx.cursor()
    try:
        cs.execute("SELECT current_version(), 28*15")
        result = cs.fetchone()
        print(result)
    finally:
        cs.close()
    ctx.close()
    return result
